==> react-error-app-boundary-2.4.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component, Suspense } from 'react';
import PropTypes from 'prop-types';
import MoleculeNotification from '@s-ui/react-molecule-notification';
var CLOSE_ANIMATION_TIME = 1000;

var ErrorAppBoundary =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(ErrorAppBoundary, _Component);

  function ErrorAppBoundary() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      errorCount: 0,
      hasError: false
    };

    _this.handleCloseNotification = function () {
      setTimeout(function () {
        return _this.setState({
          hasError: false
        });
      }, CLOSE_ANIMATION_TIME);
    };

    return _this;
  }

  var _proto = ErrorAppBoundary.prototype;

  _proto.componentDidCatch = function componentDidCatch(errorMessage, errorStack) {
    var _this$props = this.props,
        errorThreshold = _this$props.errorThreshold,
        onError = _this$props.onError,
        redirectUrlOnBreakingThreshold = _this$props.redirectUrlOnBreakingThreshold,
        silent = _this$props.silent;
    var errorCount = this.state.errorCount;
    onError({
      errorMessage: errorMessage,
      errorStack: errorStack
    }); // if silent prop is activated, then only log on the console and don't show notification

    if (silent) {
      console.error(silent);
      return;
    }

    this.setState({
      errorCount: errorCount + 1
    });
    return errorCount >= errorThreshold ? redirectUrlOnBreakingThreshold && (window.location.href = redirectUrlOnBreakingThreshold) : this.setState({
      hasError: true
    });
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.errorCount <= nextProps.errorThreshold;
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        buttonLabel = _this$props2.buttonLabel,
        children = _this$props2.children,
        message = _this$props2.message,
        silent = _this$props2.silent;
    return React.createElement(React.Fragment, null, children, this.state.hasError && !silent && React.createElement("div", {
      className: "sui-ErrorAppBoundary-notification"
    }, React.createElement(Suspense, {
      fallback: React.createElement("div", null)
    }, React.createElement(MoleculeNotification, {
      buttons: [{
        type: 'secondary',
        negative: true,
        children: buttonLabel,
        onClick: this.handleCloseNotification
      }],
      onClose: this.handleCloseNotification,
      type: "warning",
      text: message,
      position: "bottom"
    }))));
  };

  return ErrorAppBoundary;
}(Component);

ErrorAppBoundary.displayName = 'ErrorAppBoundary';
ErrorAppBoundary.defaultProps = {
  buttonLabel: 'OK',
  message: 'Error',
  errorThreshold: 4,
  silent: false,
  onError: function onError(_ref) {
    var errorMessage = _ref.errorMessage,
        errorStack = _ref.errorStack;
    return console.error({
      errorMessage: errorMessage,
      errorStack: errorStack
    });
  } // eslint-disable-line

};
export default ErrorAppBoundary;

==> react-error-app-boundary-2.5.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component, Suspense } from 'react';
import PropTypes from 'prop-types';
import MoleculeNotification from '@s-ui/react-molecule-notification';
var CLOSE_ANIMATION_TIME = 1000;

var ErrorAppBoundary = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ErrorAppBoundary, _Component);

  function ErrorAppBoundary() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      errorCount: 0,
      hasError: false
    };

    _this.handleCloseNotification = function () {
      setTimeout(function () {
        return _this.setState({
          hasError: false
        });
      }, CLOSE_ANIMATION_TIME);
    };

    return _this;
  }

  var _proto = ErrorAppBoundary.prototype;

  _proto.componentDidCatch = function componentDidCatch(errorMessage, errorStack) {
    var _this$props = this.props,
        errorThreshold = _this$props.errorThreshold,
        onError = _this$props.onError,
        redirectUrlOnBreakingThreshold = _this$props.redirectUrlOnBreakingThreshold,
        silent = _this$props.silent;
    var errorCount = this.state.errorCount;
    onError({
      errorMessage: errorMessage,
      errorStack: errorStack
    }); // if silent prop is activated, then only log on the console and don't show notification

    if (silent) {
      console.error(silent);
      return;
    }

    this.setState({
      errorCount: errorCount + 1
    });
    return errorCount >= errorThreshold ? redirectUrlOnBreakingThreshold && (window.location.href = redirectUrlOnBreakingThreshold) : this.setState({
      hasError: true
    });
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.errorCount <= nextProps.errorThreshold;
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        buttonLabel = _this$props2.buttonLabel,
        children = _this$props2.children,
        message = _this$props2.message,
        silent = _this$props2.silent;
    return React.createElement(React.Fragment, null, children, this.state.hasError && !silent && React.createElement("div", {
      className: "sui-ErrorAppBoundary-notification"
    }, React.createElement(Suspense, {
      fallback: React.createElement("div", null)
    }, React.createElement(MoleculeNotification, {
      buttons: [{
        type: 'secondary',
        negative: true,
        children: buttonLabel,
        onClick: this.handleCloseNotification
      }],
      onClose: this.handleCloseNotification,
      type: "warning",
      text: message,
      position: "bottom"
    }))));
  };

  return ErrorAppBoundary;
}(Component);

ErrorAppBoundary.displayName = 'ErrorAppBoundary';
ErrorAppBoundary.defaultProps = {
  buttonLabel: 'OK',
  message: 'Error',
  errorThreshold: 4,
  silent: false,
  onError: function onError(_ref) {
    var errorMessage = _ref.errorMessage,
        errorStack = _ref.errorStack;
    return console.error({
      errorMessage: errorMessage,
      errorStack: errorStack
    });
  } // eslint-disable-line

};
export default ErrorAppBoundary;
